==> zio-aws-xray_2.13-5.17.130.6-sources.jar: zio/aws/xray/model/ErrorRootCauseService.scala <==
package zio.aws.xray.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.xray.model.primitives.NullableBoolean
import scala.jdk.CollectionConverters._
final case class ErrorRootCauseService(
    name: Option[String] = None,
    names: Option[Iterable[String]] = None,
    `type`: Option[String] = None,
    accountId: Option[String] = None,
    entityPath: Option[Iterable[zio.aws.xray.model.ErrorRootCauseEntity]] =
      None,
    inferred: Option[NullableBoolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.xray.model.ErrorRootCauseService = {
    import ErrorRootCauseService.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.xray.model.ErrorRootCauseService
      .builder()
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(
        names.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.names)
      .optionallyWith(`type`.map(value => value: java.lang.String))(_.`type`)
      .optionallyWith(accountId.map(value => value: java.lang.String))(
        _.accountId
      )
      .optionallyWith(
        entityPath.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.entityPath)
      .optionallyWith(inferred.map(value => value: java.lang.Boolean))(
        _.inferred
      )
      .build()
  }
  def asReadOnly: zio.aws.xray.model.ErrorRootCauseService.ReadOnly =
    zio.aws.xray.model.ErrorRootCauseService.wrap(buildAwsValue())
}
object ErrorRootCauseService {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.xray.model.ErrorRootCauseService
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.xray.model.ErrorRootCauseService =
      zio.aws.xray.model.ErrorRootCauseService(
        name.map(value => value),
        names.map(value => value),
        `type`.map(value => value),
        accountId.map(value => value),
        entityPath.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        inferred.map(value => value)
      )
    def name: Option[String]
    def names: Option[List[String]]
    def `type`: Option[String]
    def accountId: Option[String]
    def entityPath
        : Option[List[zio.aws.xray.model.ErrorRootCauseEntity.ReadOnly]]
    def inferred: Option[NullableBoolean]
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getNames: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("names", names)
    def getType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("type", `type`)
    def getAccountId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getEntityPath: ZIO[Any, AwsError, List[
      zio.aws.xray.model.ErrorRootCauseEntity.ReadOnly
    ]] = AwsError.unwrapOptionField("entityPath", entityPath)
    def getInferred: ZIO[Any, AwsError, NullableBoolean] =
      AwsError.unwrapOptionField("inferred", inferred)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.xray.model.ErrorRootCauseService
  ) extends zio.aws.xray.model.ErrorRootCauseService.ReadOnly {
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
    override val names: Option[List[String]] = scala
      .Option(impl.names())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val `type`: Option[String] =
      scala.Option(impl.`type`()).map(value => value: String)
    override val accountId: Option[String] =
      scala.Option(impl.accountId()).map(value => value: String)
    override val entityPath
        : Option[List[zio.aws.xray.model.ErrorRootCauseEntity.ReadOnly]] = scala
      .Option(impl.entityPath())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.xray.model.ErrorRootCauseEntity.wrap(item)
        }.toList
      )
    override val inferred: Option[NullableBoolean] =
      scala.Option(impl.inferred()).map(value => value: NullableBoolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.xray.model.ErrorRootCauseService
  ): zio.aws.xray.model.ErrorRootCauseService.ReadOnly = new Wrapper(impl)
}

==> zio-aws-xray_2.13-5.17.167.1-sources.jar: zio/aws/xray/model/ErrorRootCauseService.scala <==
package zio.aws.xray.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.xray.model.primitives.NullableBoolean
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ErrorRootCauseService(
    name: Optional[String] = Optional.Absent,
    names: Optional[Iterable[String]] = Optional.Absent,
    `type`: Optional[String] = Optional.Absent,
    accountId: Optional[String] = Optional.Absent,
    entityPath: Optional[Iterable[zio.aws.xray.model.ErrorRootCauseEntity]] =
      Optional.Absent,
    inferred: Optional[NullableBoolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.xray.model.ErrorRootCauseService = {
    import ErrorRootCauseService.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.xray.model.ErrorRootCauseService
      .builder()
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(
        names.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.names)
      .optionallyWith(`type`.map(value => value: java.lang.String))(_.`type`)
      .optionallyWith(accountId.map(value => value: java.lang.String))(
        _.accountId
      )
      .optionallyWith(
        entityPath.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.entityPath)
      .optionallyWith(inferred.map(value => value: java.lang.Boolean))(
        _.inferred
      )
      .build()
  }
  def asReadOnly: zio.aws.xray.model.ErrorRootCauseService.ReadOnly =
    zio.aws.xray.model.ErrorRootCauseService.wrap(buildAwsValue())
}
object ErrorRootCauseService {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.xray.model.ErrorRootCauseService
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.xray.model.ErrorRootCauseService =
      zio.aws.xray.model.ErrorRootCauseService(
        name.map(value => value),
        names.map(value => value),
        `type`.map(value => value),
        accountId.map(value => value),
        entityPath.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        inferred.map(value => value)
      )
    def name: Optional[String]
    def names: Optional[List[String]]
    def `type`: Optional[String]
    def accountId: Optional[String]
    def entityPath
        : Optional[List[zio.aws.xray.model.ErrorRootCauseEntity.ReadOnly]]
    def inferred: Optional[NullableBoolean]
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getNames: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("names", names)
    def getType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("type", `type`)
    def getAccountId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getEntityPath: ZIO[Any, AwsError, List[
      zio.aws.xray.model.ErrorRootCauseEntity.ReadOnly
    ]] = AwsError.unwrapOptionField("entityPath", entityPath)
    def getInferred: ZIO[Any, AwsError, NullableBoolean] =
      AwsError.unwrapOptionField("inferred", inferred)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.xray.model.ErrorRootCauseService
  ) extends zio.aws.xray.model.ErrorRootCauseService.ReadOnly {
    override val name: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: String)
    override val names: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.names())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val `type`: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.`type`())
      .map(value => value: String)
    override val accountId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.accountId())
      .map(value => value: String)
    override val entityPath
        : Optional[List[zio.aws.xray.model.ErrorRootCauseEntity.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.entityPath())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.xray.model.ErrorRootCauseEntity.wrap(item)
          }.toList
        )
    override val inferred: Optional[NullableBoolean] = zio.aws.core.internal
      .optionalFromNullable(impl.inferred())
      .map(value => value: NullableBoolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.xray.model.ErrorRootCauseService
  ): zio.aws.xray.model.ErrorRootCauseService.ReadOnly = new Wrapper(impl)
}
